@@ -1,10 +1,8 @@
-HWChisqMat <-
-function(X,...) {
-
+HWChisqMat <- function(X,...) {
+# applys chi-square test for HWE to all rows of X.
 pvalvec <- NULL
 chisqvec <- NULL
 Dvec <- NULL
-
 for (i in 1:nrow(X)) {
    out <- HWChisq(X[i,],...)
    pvalvec <- c(pvalvec,out$pval)
